@@ -1,5 +1,7 @@
 from .base64_utils import to_gbk_base64
+from .parse_img import parse_img
 from .time_utils import cal_time
 from .time_utils import get_now_date
 from .time_utils import get_timestamp
+from .time_utils import get_timestamp_mil
 from .time_utils import get_timestamp_str
